PipePair

Struct PipePair 

pub struct PipePair {
    pub notif_r: OwnedFd,
    pub notif_w: OwnedFd,
    pub ready_r: OwnedFd,
    pub ready_w: OwnedFd,
}
Pipes for parent-child communication after fork().

Fields

notif_r: OwnedFd

Parent reads the notif fd number written by the child.

notif_w: OwnedFd

Child writes the notif fd number to the parent.

ready_r: OwnedFd

Child reads the “supervisor ready” signal from the parent.

ready_w: OwnedFd

Parent writes the “supervisor ready” signal to the child.

Implementations

Source

impl PipePair

pub fn new() -> Result<Self>

Create two pipe pairs using pipe2(O_CLOEXEC).