pub struct PolicyEvent {
pub event: SyscallEvent,
pub gate: Option<Sender<Verdict>>,
}Expand description
An event sent from the supervisor to the policy callback thread.
Fields
event: SyscallEventgate: Option<Sender<Verdict>>If Some, the supervisor blocks until this is signaled. Used for execve to allow pre-execution policy changes. The Verdict is sent back to control allow/deny.