pub struct PipePair {
pub notif_r: OwnedFd,
pub notif_w: OwnedFd,
pub ready_r: OwnedFd,
pub ready_w: OwnedFd,
}Expand description
Pipes for parent-child communication after fork().
Fields
notif_r: OwnedFdParent reads the notif fd number written by the child.
notif_w: OwnedFdChild writes the notif fd number to the parent.
ready_r: OwnedFdChild reads the “supervisor ready” signal from the parent.
ready_w: OwnedFdParent writes the “supervisor ready” signal to the child.
Implementations